==> lnl-3.1.0.tar.gz: lnl-3.1.0/src/gmain.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: gmain.h,v 1.46 2006/01/31 08:04:37 bowkenken Exp $
***************************************************************/

#ifndef	GMAIN_H
#define	GMAIN_H

/***************************************************************
* ᥤ
***************************************************************/

#if	defined( D_WIN )
# include	"config-win.h"
#elif	defined( D_DOS )
# include	"lnl-dos/config-dos.h"
#endif

#if	HAVE_CONFIG_H
# include	"config.h"
#endif	/* HAVE_CONFIG_H */

#if	HAVE_STDLIB_H
# include	<stdlib.h>
#endif	/* HAVE_STDLIB_H */

#if	HAVE_STDDEF_H
# include	<stddef.h>
#endif	/* HAVE_STDDEF_H */

#if	HAVE_STDIO_H
# include	<stdio.h>
#endif	/* HAVE_STDIO_H */

#if	HAVE_STDARG_H
# include	<stdarg.h>
#endif	/* HAVE_STDARG_H */

#if	HAVE_LIMITS_H
# include	<limits.h>
#endif	/* HAVE_LIMITS_H */

#if	HAVE_STRING_H
# include	<string.h>
#endif	/* HAVE_STRING_H */

#if	HAVE_STRINGS_H
# include	<strings.h>
#endif	/* HAVE_STRING_H */

#if	HAVE_CTYPE_H
# include	<ctype.h>
#endif	/* HAVE_CTYPE_H */

#if	HAVE_TIME_H
# include	<time.h>
#endif	/* HAVE_TIME_H */

#if	HAVE_MATH_H
# include	<math.h>
#endif	/* HAVE_MATH_H */

#if	HAVE_DIRECT_H
# include <direct.h>
#endif	/* HAVE_DIRECT_H */

#if	HAVE_SYS_STAT_H
# include	<sys/stat.h>
#endif	/* HAVE_SYS_STAT_H */

#if	HAVE_UNISTD_H
# include	<unistd.h>
#endif	/* HAVE_UNISTD_H */

#ifndef	EXIT_SUCCESS
#define	EXIT_SUCCESS	0
#endif	/* EXIT_SUCCESS */

#ifndef	EXIT_FAILURE
#define	EXIT_FAILURE	1
#endif	/* EXIT_FAILURE */

/***************************************************************/

#include	"misc.h"
#include	"turn.h"

#include	"msg-t.h"

/***************************************************************
* 
***************************************************************/

/* Ϥɤɤफ? */

typedef enum {
	GUI_KEY_KIND_CONSOLE,
	GUI_KEY_KIND_CLASS_KEY,
	GUI_KEY_KIND_KEY_BUF_INTERRUPT,
	GUI_KEY_KIND_MAX_N,
} gui_key_kind_t;

/***************************************************************
* ѿ
***************************************************************/

#include	"extern.h"

/* ե饰 */

/* CUI ⥸塼뤬Ѥߤ? */
EXTERN bool_t	g_flg_init;

/* CUI ⡼ */
EXTERN bool_t	g_flg_cui;

/* GUI ⡼ */
EXTERN bool_t	g_flg_gui;

/* Ϥɤɤफ? */
EXTERN gui_key_kind_t	g_gui_key_kind;

/* Хåե򥯥ꥢ */
EXTERN bool_t	g_flg_clr_key_buf;

/* Хåե򥯥ꥢʥ˥塼 */
EXTERN bool_t	g_flg_clr_key_buf_menu;

/* Ϥ줿ɽ */
EXTERN bool_t	g_flg_echo_key;

/* ̤ curses 饤֥Ѥ */
EXTERN bool_t	g_flg_use_curs;

/* 롦Ѥ */
EXTERN bool_t	g_flg_use_keypad;

/* ե졼ࡦ졼Ȥ¬ */
EXTERN bool_t	g_flg_measure_clk_tck;

/* ǥХå⡼ */
EXTERN bool_t	g_flg_debug;

#endif	/* GMAIN_H */

==> lnl-3.1.1.tar.gz: lnl-3.1.1/src/gmain.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: gmain.h,v 1.47 2006/09/06 23:04:23 bowkenken Exp $
***************************************************************/

#ifndef	GMAIN_H
#define	GMAIN_H

/***************************************************************
* ᥤ
***************************************************************/

#if	defined( D_WIN )
# include	"config-win.h"
#elif	defined( D_DOS )
# include	"lnl-dos/config-dos.h"
#endif

#if	HAVE_CONFIG_H
# include	"config.h"
#endif	/* HAVE_CONFIG_H */

#if	HAVE_STDLIB_H
# include	<stdlib.h>
#endif	/* HAVE_STDLIB_H */

#if	HAVE_STDDEF_H
# include	<stddef.h>
#endif	/* HAVE_STDDEF_H */

#if	HAVE_STDIO_H
# include	<stdio.h>
#endif	/* HAVE_STDIO_H */

#if	HAVE_STDARG_H
# include	<stdarg.h>
#endif	/* HAVE_STDARG_H */

#if	HAVE_LIMITS_H
# include	<limits.h>
#endif	/* HAVE_LIMITS_H */

#if	HAVE_STRING_H
# include	<string.h>
#endif	/* HAVE_STRING_H */

#if	HAVE_STRINGS_H
# include	<strings.h>
#endif	/* HAVE_STRING_H */

#if	HAVE_CTYPE_H
# include	<ctype.h>
#endif	/* HAVE_CTYPE_H */

#if	HAVE_TIME_H
# include	<time.h>
#endif	/* HAVE_TIME_H */

#if	HAVE_MATH_H
# include	<math.h>
#endif	/* HAVE_MATH_H */

#if	HAVE_DIRECT_H
# include <direct.h>
#endif	/* HAVE_DIRECT_H */

#if	HAVE_SYS_STAT_H
# include	<sys/stat.h>
#endif	/* HAVE_SYS_STAT_H */

#if	HAVE_UNISTD_H
# include	<unistd.h>
#endif	/* HAVE_UNISTD_H */

#ifndef	EXIT_SUCCESS
#define	EXIT_SUCCESS	0
#endif	/* EXIT_SUCCESS */

#ifndef	EXIT_FAILURE
#define	EXIT_FAILURE	1
#endif	/* EXIT_FAILURE */

/***************************************************************/

#include	"misc.h"
#include	"turn.h"

#include	"msg-t.h"

/***************************************************************
* 
***************************************************************/

/* Ϥɤɤफ? */

typedef enum {
	GUI_KEY_KIND_CONSOLE,
	GUI_KEY_KIND_CLASS_KEY,
	GUI_KEY_KIND_KEY_BUF_INTERRUPT,
	GUI_KEY_KIND_MAX_N,
} gui_key_kind_t;

/***************************************************************
* ѿ
***************************************************************/

#include	"extern.h"

/* ե饰 */

/* CUI ⥸塼뤬Ѥߤ? */
EXTERN bool_t	g_flg_init;

/* CUI ⡼ */
EXTERN bool_t	g_flg_cui;

/* GUI ⡼ */
EXTERN bool_t	g_flg_gui;

/* Ϥɤɤफ? */
EXTERN gui_key_kind_t	g_gui_key_kind;

/* ХåեΥꥢ򥪥ץǻꤵ줿? */
EXTERN bool_t	g_flg_clr_key_buf_arg_overwrite;

/* ХåեΥꥢ򥪥ץǻ */
EXTERN bool_t	g_flg_clr_key_buf_arg;

/* Хåե򥯥ꥢ */
EXTERN bool_t	g_flg_clr_key_buf;

/* Хåե򥯥ꥢʥ˥塼 */
EXTERN bool_t	g_flg_clr_key_buf_menu;

/* Ϥ줿ɽ */
EXTERN bool_t	g_flg_echo_key;

/* ̤ curses 饤֥Ѥ */
EXTERN bool_t	g_flg_use_curs;

/* 롦Ѥ */
EXTERN bool_t	g_flg_use_keypad;

/* ե졼ࡦ졼Ȥ¬ */
EXTERN bool_t	g_flg_measure_clk_tck;

/* ǥХå⡼ */
EXTERN bool_t	g_flg_debug;

#endif	/* GMAIN_H */
